pub trait PartialEqAny {
// Required method
fn partial_equal_any(&self, other: &dyn Any) -> bool;
}Expand description
Compares the given value with an Any trait object. Register this trait if you want to compare two Multitrait objects with the TryPartialEq trait.
Required Methods
fn partial_equal_any(&self, other: &dyn Any) -> bool
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".