pub unsafe trait RawClone { }Expand description
Returns a raw pointer to the cloned data. This will leak the memory of the underlying pointer. This trait is implemented for all types that implement clone so you can pass this trait to the object constructor. This way the given object can be cloned with TryClone.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".